@@ -1,24 +1,26 @@
 """Module for storing alias array."""
+from typing import List, Optional, Tuple
+
 from pyvlx.exception import PyVLXException
 
 
 class AliasArray:
     """Object for storing alias array."""
 
-    def __init__(self, raw=None):
+    def __init__(self, raw: Optional[bytes] = None):
         """Initialize alias array."""
-        self.alias_array_ = []
+        self.alias_array_: List[Tuple[bytes, bytes]] = []
         if raw is not None:
             self.parse_raw(raw)
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return human readable string."""
         return ", ".join(
             "{:02x}{:02x}={:02x}{:02x}".format(c[0][0], c[0][1], c[1][0], c[1][1])
             for c in self.alias_array_
         )
 
-    def __bytes__(self):
+    def __bytes__(self) -> bytes:
         """Get raw bytes of alias array."""
         ret = bytes([len(self.alias_array_)])
         for alias in self.alias_array_:
@@ -26,7 +28,7 @@ class AliasArray:
         ret += bytes((5 - len(self.alias_array_)) * 4)
         return ret
 
-    def parse_raw(self, raw):
+    def parse_raw(self, raw: bytes) -> None:
         """Parse alias array from raw bytes."""
         if not isinstance(raw, bytes):
             raise PyVLXException("AliasArray::invalid_type_if_raw", type_raw=type(raw))
