@@ -9,11 +9,11 @@ class FrameGatewayFactoryDefaultRequest(FrameBase):
 
     PAYLOAD_LEN = 0
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Init Frame."""
         super().__init__(Command.GW_SET_FACTORY_DEFAULT_REQ)
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return human readable string."""
         return '<{}/>'.format(type(self).__name__)
 
@@ -23,10 +23,10 @@ class FrameGatewayFactoryDefaultConfirmation(FrameBase):
 
     PAYLOAD_LEN = 0
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Init Frame."""
         super().__init__(Command.GW_SET_FACTORY_DEFAULT_CFM)
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return human readable string."""
         return '<{}/>'.format(type(self).__name__)
