@@ -9,7 +9,7 @@ class FrameGetNetworkSetupRequest(FrameBase):
 
     PAYLOAD_LEN = 0
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Init Frame."""
         super().__init__(Command.GW_GET_NETWORK_SETUP_REQ)
 
@@ -19,8 +19,8 @@ class FrameGetNetworkSetupConfirmation(FrameBase):
 
     PAYLOAD_LEN = 13
 
-    def __init__(self, ipaddress=bytes(4), netmask=bytes(4), gateway=bytes(4),
-                 dhcp=DHCPParameter.DISABLE):
+    def __init__(self, ipaddress: bytes = bytes(4), netmask: bytes = bytes(4), gateway: bytes = bytes(4),
+                 dhcp: DHCPParameter = DHCPParameter.DISABLE):
         """Init Frame."""
         super().__init__(Command.GW_GET_NETWORK_SETUP_CFM)
         self._ipaddress = ipaddress
@@ -29,21 +29,21 @@ class FrameGetNetworkSetupConfirmation(FrameBase):
         self.dhcp = dhcp
 
     @property
-    def ipaddress(self):
+    def ipaddress(self) -> str:
         """Return ipaddress as human readable string."""
         return ".".join(str(c) for c in self._ipaddress)
 
     @property
-    def netmask(self):
+    def netmask(self) -> str:
         """Return ipaddress as human readable string."""
         return ".".join(str(c) for c in self._netmask)
 
     @property
-    def gateway(self):
+    def gateway(self) -> str:
         """Return ipaddress as human readable string."""
         return ".".join(str(c) for c in self._gateway)
 
-    def get_payload(self):
+    def get_payload(self) -> bytes:
         """Return Payload."""
         payload = self._ipaddress
         payload += self._netmask
@@ -51,14 +51,14 @@ class FrameGetNetworkSetupConfirmation(FrameBase):
         payload += bytes(self.dhcp.value)
         return payload
 
-    def from_payload(self, payload):
+    def from_payload(self, payload: bytes) -> None:
         """Init frame from binary data."""
         self._ipaddress = payload[0:4]
         self._netmask = payload[4:8]
         self._gateway = payload[8:12]
         self.dhcp = DHCPParameter(payload[12])
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return human readable string."""
         return '<{} ipaddress="{}" netmask="{}" gateway="{}" dhcp="{}"/>'.format(
             type(self).__name__, self.ipaddress, self.netmask, self.gateway, self.dhcp)
