@@ -2,8 +2,10 @@
 import struct
 from datetime import datetime
 from enum import Enum
+from typing import Optional
 
-from pyvlx.const import Command, NodeTypeWithSubtype, NodeVariation, Velocity
+from pyvlx.const import (
+    Command, NodeTypeWithSubtype, NodeVariation, OperatingState, Velocity)
 from pyvlx.exception import PyVLXException
 from pyvlx.parameter import Parameter
 from pyvlx.string_helper import bytes_to_string, string_to_bytes
@@ -17,20 +19,21 @@ class FrameGetNodeInformationRequest(FrameBase):
 
     PAYLOAD_LEN = 1
 
-    def __init__(self, node_id=None):
+    def __init__(self, node_id: Optional[int] = None):
         """Init Frame."""
         super().__init__(Command.GW_GET_NODE_INFORMATION_REQ)
         self.node_id = node_id
 
-    def get_payload(self):
+    def get_payload(self) -> bytes:
         """Return Payload."""
+        assert self.node_id is not None
         return bytes([self.node_id])
 
-    def from_payload(self, payload):
+    def from_payload(self, payload: bytes) -> None:
         """Init frame from binary data."""
         self.node_id = payload[0]
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return human readable string."""
         return '<{} node_id="{}"/>'.format(type(self).__name__, self.node_id)
 
@@ -49,22 +52,23 @@ class FrameGetNodeInformationConfirmation(FrameBase):
 
     PAYLOAD_LEN = 2
 
-    def __init__(self, status=NodeInformationStatus.OK, node_id=None):
+    def __init__(self, status: NodeInformationStatus = NodeInformationStatus.OK, node_id: Optional[int] = None):
         """Init Frame."""
         super().__init__(Command.GW_GET_NODE_INFORMATION_CFM)
         self.status = status
         self.node_id = node_id
 
-    def get_payload(self):
+    def get_payload(self) -> bytes:
         """Return Payload."""
+        assert self.node_id is not None
         return bytes([self.status.value, self.node_id])
 
-    def from_payload(self, payload):
+    def from_payload(self, payload: bytes) -> None:
         """Init frame from binary data."""
         self.status = NodeInformationStatus(payload[0])
         self.node_id = payload[1]
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return human readable string."""
         return '<{} node_id="{}" status="{}"/>'.format(
             type(self).__name__, self.node_id, self.status
@@ -76,7 +80,7 @@ class FrameGetNodeInformationNotification(FrameBase):
 
     PAYLOAD_LEN = 124
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Init Frame."""
         super().__init__(Command.GW_GET_NODE_INFORMATION_NTF)
         self.node_id = 0
@@ -91,7 +95,7 @@ class FrameGetNodeInformationNotification(FrameBase):
         self.power_mode = 0
         self.build_number = 0
         self._serial_number = bytes(8)
-        self.state = 0
+        self.state = OperatingState.UNKNOWN
         self.current_position = Parameter()
         self.target = Parameter()
         self.current_position_fp1 = Parameter()
@@ -103,14 +107,14 @@ class FrameGetNodeInformationNotification(FrameBase):
         self.alias_array = AliasArray()
 
     @property
-    def serial_number(self):
+    def serial_number(self) -> Optional[str]:
         """Property for serial number in a human readable way."""
         if self._serial_number == bytes(8):
             return None
         return ":".join("{:02x}".format(c) for c in self._serial_number)
 
     @serial_number.setter
-    def serial_number(self, serial_number):
+    def serial_number(self, serial_number: Optional[str]) -> None:
         """Set serial number."""
         if serial_number is None:
             self._serial_number = bytes(8)
@@ -121,7 +125,7 @@ class FrameGetNodeInformationNotification(FrameBase):
         if len(self._serial_number) != 8:
             raise PyVLXException("could_not_parse_serial_number")
 
-    def get_payload(self):
+    def get_payload(self) -> bytes:
         """Return Payload."""
         payload = bytes()
         payload += bytes([self.node_id])
@@ -138,7 +142,7 @@ class FrameGetNodeInformationNotification(FrameBase):
             [self.build_number]
         )  # <-- hey @VELUX: your documentation is wrong here
         payload += bytes(self._serial_number)
-        payload += bytes([self.state])
+        payload += bytes([self.state.value])
         payload += bytes(self.current_position.raw)
         payload += bytes(self.target.raw)
         payload += bytes(self.current_position_fp1.raw)
@@ -150,7 +154,7 @@ class FrameGetNodeInformationNotification(FrameBase):
         payload += bytes(self.alias_array)
         return payload
 
-    def from_payload(self, payload):
+    def from_payload(self, payload: bytes) -> None:
         """Init frame from binary data."""
         self.node_id = payload[0]
         self.order = payload[1] * 256 + payload[2]
@@ -166,7 +170,7 @@ class FrameGetNodeInformationNotification(FrameBase):
             75
         ]  # <-- hey @VELUX: your documentation is wrong here
         self._serial_number = payload[76:84]
-        self.state = payload[84]
+        self.state = OperatingState(payload[84])
         self.current_position = Parameter(payload[85:87])
         self.target = Parameter(payload[87:89])
         self.current_position_fp1 = Parameter(payload[89:91])
@@ -178,11 +182,11 @@ class FrameGetNodeInformationNotification(FrameBase):
         self.alias_array = AliasArray(payload[103:125])
 
     @property
-    def timestamp_formatted(self):
+    def timestamp_formatted(self) -> str:
         """Return time as human readable string."""
         return datetime.fromtimestamp(self.timestamp).strftime("%Y-%m-%d %H:%M:%S")
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return human readable string."""
         return (
             '<{} node_id="{}" order="{}" '
@@ -205,7 +209,7 @@ class FrameGetNodeInformationNotification(FrameBase):
                 self.power_mode,
                 self.build_number,
                 self.serial_number,
-                self.state,
+                self.state.name,
                 self.current_position,
                 self.target,
                 self.current_position_fp1,
