@@ -1,25 +1,30 @@
 """Module for retrieving node information from API."""
+from typing import TYPE_CHECKING, List
+
 from pyvlx.log import PYVLXLOG
 
 from .api_event import ApiEvent
 from .frames import (
-    FrameGetAllNodesInformationConfirmation,
+    FrameBase, FrameGetAllNodesInformationConfirmation,
     FrameGetAllNodesInformationFinishedNotification,
     FrameGetAllNodesInformationNotification,
     FrameGetAllNodesInformationRequest)
 
+if TYPE_CHECKING:
+    from pyvlx import PyVLX
+
 
 class GetAllNodesInformation(ApiEvent):
-    """Class for retrieving node informationfrom API."""
+    """Class for retrieving node information from API."""
 
-    def __init__(self, pyvlx):
+    def __init__(self, pyvlx: "PyVLX"):
         """Initialize SceneList class."""
         super().__init__(pyvlx=pyvlx)
         self.number_of_nodes = 0
         self.success = False
-        self.notification_frames = []
+        self.notification_frames: List[FrameGetAllNodesInformationNotification] = []
 
-    async def handle_frame(self, frame):
+    async def handle_frame(self, frame: FrameBase) -> bool:
         """Handle incoming API frame, return True if this was the expected frame."""
         if isinstance(frame, FrameGetAllNodesInformationConfirmation):
             self.number_of_nodes = frame.number_of_nodes
@@ -36,6 +41,6 @@ class GetAllNodesInformation(ApiEvent):
             return True
         return False
 
-    def request_frame(self):
+    def request_frame(self) -> FrameGetAllNodesInformationRequest:
         """Construct initiating frame."""
         return FrameGetAllNodesInformationRequest()
