@@ -1,7 +1,8 @@
 """Module for enum and consts."""
-
 from enum import Enum
 
+from typing_extensions import Any
+
 
 class Command(Enum):
     """Enum class for GW Command bytes."""
@@ -294,6 +295,9 @@ class NodeTypeWithSubtype(Enum):
     DUAL_ROLLER_SHUTTER = 0x0340
     ON_OFF_SWITCH = 0x03C0
     HORIZONTAL_AWNING = 0x0400
+    # Not documented by Velux but reported by some devices
+    # Velux support refuses to provide additional information about this node sub type
+    HORIZONTAL_AWNING_ALT = 0x0401
     EXTERIOR_VENETIAN_BLIND = 0x0440
     LOUVER_BLIND = 0x0480
     CURTAIN_TRACK = 0x04C0
@@ -579,6 +583,10 @@ class OperatingState(Enum):
     DONE = 5
     UNKNOWN = 255
 
+    @classmethod
+    def _missing_(cls, value: object) -> Any:
+        return cls.UNKNOWN
+
 
 class StatusReply(Enum):
     """Enum Class for Node Status Reply."""
@@ -630,6 +638,10 @@ class StatusReply(Enum):
     LIMITATION_BY_AUTOMATIC_CYCLE = 0xED              # Indicates the parameter was limited by an automatic cycle.
     LIMITATION_BY_EMERGENCY = 0xEE                    # Indicates the parameter was limited by an emergency.
 
+    @classmethod
+    def _missing_(cls, value: object) -> Any:
+        return cls.UNKNOWN_STATUS_REPLY
+
 
 class StatusId(Enum):
     """Enum Class for Status ID Reply."""
@@ -647,9 +659,13 @@ class StatusId(Enum):
     STATUS_EMERGENCY = 0x0C        # The status is from an emergency or a security generated action.
     STATUS_UNKNOWN = 0xFF          # The status is from from an unknown command originator action.
 
+    @classmethod
+    def _missing_(cls, value: object) -> Any:
+        return cls.STATUS_UNKNOWN
+
 
 class RunStatus(Enum):
-    """Enum Class for Node Runstatus."""
+    """Enum Class for Node RunStatus."""
 
     EXECUTION_COMPLETED = 0  # Execution is completed with no errors.
     EXECUTION_FAILED = 1     # Execution has failed. (Get specifics in the following error code)
@@ -663,3 +679,8 @@ class StatusType(Enum):
     REQUEST_CURRENT_POSITION = 1  # Request Current Position
     REQUEST_REMAINING_TIME = 2  # Request Remaining Time
     REQUEST_MAIN_INFO = 3  # Request Main Info
+    REQUEST_UNKNOWN = 255  # Request Unknown
+
+    @classmethod
+    def _missing_(cls, value: object) -> Any:
+        return cls.REQUEST_UNKNOWN
