@@ -1,4 +1,4 @@
 """Module for global PyVLX logging object."""
 import logging
 
-PYVLXLOG = logging.getLogger('pyvlx')
+PYVLXLOG = logging.getLogger("pyvlx")
