@@ -1,15 +1,31 @@
 """Helper module for Node objects."""
+from typing import TYPE_CHECKING, Optional, Union
+
+from .api.frames import (
+    FrameGetAllNodesInformationNotification,
+    FrameGetNodeInformationNotification)
 from .const import NodeTypeWithSubtype
 from .lightening_device import Light
 from .log import PYVLXLOG
+from .node import Node
 from .on_off_switch import OnOffSwitch
 from .opening_device import (
-    Awning, Blade, Blind, GarageDoor, Gate, RollerShutter, Window)
+    Awning, Blade, Blind, DualRollerShutter, GarageDoor, Gate, RollerShutter,
+    Window)
+
+if TYPE_CHECKING:
+    from pyvlx import PyVLX
 
 
-def convert_frame_to_node(pyvlx, frame):
+def convert_frame_to_node(
+    pyvlx: "PyVLX",
+    frame: Union[
+        FrameGetNodeInformationNotification, FrameGetAllNodesInformationNotification
+    ],
+) -> Optional[Node]:
     """Convert FrameGet[All]Node[s]InformationNotification into Node object."""
     # pylint: disable=too-many-return-statements
+
     if frame.node_type == NodeTypeWithSubtype.WINDOW_OPENER:
         return Window(
             pyvlx=pyvlx,
@@ -30,10 +46,18 @@ def convert_frame_to_node(pyvlx, frame):
             rain_sensor=True,
         )
 
+    if frame.node_type == NodeTypeWithSubtype.DUAL_ROLLER_SHUTTER:
+        return DualRollerShutter(
+            pyvlx=pyvlx,
+            node_id=frame.node_id,
+            name=frame.name,
+            serial_number=frame.serial_number,
+            position_parameter=frame.current_position,
+        )
+
     if frame.node_type in [
         NodeTypeWithSubtype.ROLLER_SHUTTER,
-        NodeTypeWithSubtype.DUAL_ROLLER_SHUTTER,
-        NodeTypeWithSubtype.SWINGING_SHUTTERS
+        NodeTypeWithSubtype.SWINGING_SHUTTERS,
     ]:
         return RollerShutter(
             pyvlx=pyvlx,
@@ -72,6 +96,7 @@ def convert_frame_to_node(pyvlx, frame):
     if frame.node_type in [
         NodeTypeWithSubtype.VERTICAL_EXTERIOR_AWNING,
         NodeTypeWithSubtype.HORIZONTAL_AWNING,
+        NodeTypeWithSubtype.HORIZONTAL_AWNING_ALT,
     ]:
         return Awning(
             pyvlx=pyvlx,
